@@ -17,6 +17,7 @@ if TYPE_CHECKING:
         FilterTypeDef,
         TagTypeDef,
         InstanceStatusSummaryTypeDef,
+        TagSpecificationTypeDef,
     )
     from mypy_boto3_ec2.literals import InstanceTypeType
 
@@ -117,8 +118,8 @@ def launch(
     if additional_tags:
         tags.extend([{"Key": k, "Value": v} for k, v in additional_tags.items()])
     runargs["TagSpecifications"] = [
-        {"ResourceType": "instance", "Tags": tags},
-        {"ResourceType": "volume", "Tags": tags},
+        cast("TagSpecificationTypeDef", {"ResourceType": "instance", "Tags": tags}),
+        cast("TagSpecificationTypeDef", {"ResourceType": "volume", "Tags": tags}),
     ]
 
     if config.get("vpc", None):
@@ -211,7 +212,7 @@ def describe(
                     elif col == "DnsName":
                         desc[col] = i["PublicDnsName"] if i.get("PublicDnsName", None) != "" else i["PrivateDnsName"]
                     else:
-                        desc[col] = i[col]
+                        desc[col] = i.get(col, None)
 
                 instances.append(desc)
 
@@ -249,6 +250,10 @@ def tag(
         parts = t.split("=")
         tagdefs.append({"Key": parts[0], "Value": parts[1]})
 
+    if not name and not name_match:
+        # avoid tagging all instances when there's no name
+        raise NoInstancesError(name=name, name_match=name_match)
+
     instances = describe(config, name, name_match)
 
     ids = [i["InstanceId"] for i in instances]
@@ -316,6 +321,10 @@ def start(config: Config, name: str) -> List[Instance]:
 
     print(f"Starting instances with the name {name} ... ")
 
+    if not name:
+        # avoid starting all instances when there's no name
+        raise NoInstancesError(name=name)
+
     instances = describe(config, name)
 
     if not instances:
@@ -335,6 +344,10 @@ def stop(config: Config, name: str) -> List[Dict[str, Any]]:
 
     ec2_client = boto3.client("ec2", region_name=config.get("region", None))
 
+    if not name:
+        # avoid stopping all instances when there's no name
+        raise NoInstancesError(name=name)
+
     instances = describe(config, name)
 
     if not instances:
@@ -350,6 +363,10 @@ def terminate(config: Config, name: str) -> List[Dict[str, Any]]:
 
     ec2_client = boto3.client("ec2", region_name=config.get("region", None))
 
+    if not name:
+        # avoid terminating all instances when there's no name
+        raise NoInstancesError(name=name)
+
     instances = describe(config, name)
 
     if not instances:
@@ -367,6 +384,10 @@ def modify(config: Config, name: str, type: str) -> List[Instance]:
 
     ec2_client = boto3.client("ec2", region_name=config.get("region", None))
 
+    if not name:
+        # avoid modifying all instances when there's no name
+        raise NoInstancesError(name=name)
+
     instances = describe(config, name)
 
     if not instances:
@@ -398,6 +419,10 @@ def logs(config: Config, name: str) -> str:
 
     ec2_client = boto3.client("ec2", region_name=config.get("region", None))
 
+    if not name:
+        # avoid describing all instances when there's no name
+        raise NoInstancesError(name=name)
+
     instances = describe(config, name)
 
     if not instances:
